==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_fields/ADVREPORTSESSION_Type.java <==

package net.datastream.schemas.mp_fields;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ADVREPORTSESSION_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="ADVREPORTSESSION_Type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element name="SESSIONID" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         <element name="PREFERENCES" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         <element name="USERPREFERENCES" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         <element name="USERSESSIONID" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         <element name="USERPREFERENCEEX" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ADVREPORTSESSION_Type", propOrder = {
    "sessionid",
    "preferences",
    "userpreferences",
    "usersessionid",
    "userpreferenceex"
})
public class ADVREPORTSESSION_Type {

    @XmlElement(name = "SESSIONID", required = true)
    protected String sessionid;
    @XmlElement(name = "PREFERENCES", required = true)
    protected String preferences;
    @XmlElement(name = "USERPREFERENCES", required = true)
    protected String userpreferences;
    @XmlElement(name = "USERSESSIONID", required = true)
    protected String usersessionid;
    @XmlElement(name = "USERPREFERENCEEX", required = true)
    protected String userpreferenceex;

    /**
     * Gets the value of the sessionid property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSESSIONID() {
        return sessionid;
    }

    /**
     * Sets the value of the sessionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSESSIONID(String value) {
        this.sessionid = value;
    }

    /**
     * Gets the value of the preferences property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPREFERENCES() {
        return preferences;
    }

    /**
     * Sets the value of the preferences property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPREFERENCES(String value) {
        this.preferences = value;
    }

    /**
     * Gets the value of the userpreferences property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUSERPREFERENCES() {
        return userpreferences;
    }

    /**
     * Sets the value of the userpreferences property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUSERPREFERENCES(String value) {
        this.userpreferences = value;
    }

    /**
     * Gets the value of the usersessionid property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUSERSESSIONID() {
        return usersessionid;
    }

    /**
     * Sets the value of the usersessionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUSERSESSIONID(String value) {
        this.usersessionid = value;
    }

    /**
     * Gets the value of the userpreferenceex property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUSERPREFERENCEEX() {
        return userpreferenceex;
    }

    /**
     * Sets the value of the userpreferenceex property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUSERPREFERENCEEX(String value) {
        this.userpreferenceex = value;
    }

}

==> eam-wshub-proxyclient-12.1-3-sources.jar: net/datastream/schemas/mp_fields/ADVREPORTSESSION_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ADVREPORTSESSION_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ADVREPORTSESSION_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="SESSIONID" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="PREFERENCES" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="USERPREFERENCES" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="USERSESSIONID" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="USERPREFERENCEEX" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ADVREPORTSESSION_Type", propOrder = {
    "sessionid",
    "preferences",
    "userpreferences",
    "usersessionid",
    "userpreferenceex"
})
public class ADVREPORTSESSION_Type {

    @XmlElement(name = "SESSIONID", required = true)
    protected String sessionid;
    @XmlElement(name = "PREFERENCES", required = true)
    protected String preferences;
    @XmlElement(name = "USERPREFERENCES", required = true)
    protected String userpreferences;
    @XmlElement(name = "USERSESSIONID", required = true)
    protected String usersessionid;
    @XmlElement(name = "USERPREFERENCEEX", required = true)
    protected String userpreferenceex;

    /**
     * Gets the value of the sessionid property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSESSIONID() {
        return sessionid;
    }

    /**
     * Sets the value of the sessionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSESSIONID(String value) {
        this.sessionid = value;
    }

    /**
     * Gets the value of the preferences property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPREFERENCES() {
        return preferences;
    }

    /**
     * Sets the value of the preferences property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPREFERENCES(String value) {
        this.preferences = value;
    }

    /**
     * Gets the value of the userpreferences property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUSERPREFERENCES() {
        return userpreferences;
    }

    /**
     * Sets the value of the userpreferences property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUSERPREFERENCES(String value) {
        this.userpreferences = value;
    }

    /**
     * Gets the value of the usersessionid property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUSERSESSIONID() {
        return usersessionid;
    }

    /**
     * Sets the value of the usersessionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUSERSESSIONID(String value) {
        this.usersessionid = value;
    }

    /**
     * Gets the value of the userpreferenceex property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUSERPREFERENCEEX() {
        return userpreferenceex;
    }

    /**
     * Sets the value of the userpreferenceex property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUSERPREFERENCEEX(String value) {
        this.userpreferenceex = value;
    }

}
